#
# spec file for package audit-secondary
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without python2
%bcond_without python3
# This package contains all audit functionality except for audit-libs.
# The seperation is required to minimize unnecessary build cycles.
%define 	_name audit
Name:           audit-secondary
Version:        2.8.1
Release:        lp151.5.3.1
Summary:        Linux kernel audit subsystem utilities
License:        GPL-2.0+
Group:          System/Monitoring
Url:            http://people.redhat.com/sgrubb/audit/
Source0:        http://people.redhat.com/sgrubb/audit/%{_name}-%{version}.tar.gz
Patch1:         audit-plugins-path.patch
Patch2:         audit-no-gss.patch
Patch3:         audit-allow-manual-stop.patch
Patch4:         audit-ausearch-do-not-require-tclass.patch
Patch5:		audit-Fix-hang-on-startup.patch
BuildRequires:  audit-devel = %{version}
BuildRequires:  autoconf >= 2.12
BuildRequires:  gcc-c++
BuildRequires:  kernel-headers >= 2.6.30
BuildRequires:  libtool
BuildRequires:  libldapcpp-devel
BuildRequires:  pkgconfig
%if %{with python2}
BuildRequires:  python2-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
BuildRequires:  swig
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(libcap-ng)

%description
The audit package contains the user space utilities for storing and
processing the records generated by the audit subsystem in the
Linux kernel.

%package -n audit
Summary:        User Space Tools for Kernel Auditing
License:        LGPL-2.1+
Group:          System/Monitoring
Requires:       %{_name}-libs = %{version}
Requires:       coreutils
%{?systemd_requires}

%description -n audit
The audit package contains the user space utilities for storing and
processing the audit records generated by the audit subsystem in the
Linux kernel.

%package -n     python2-audit
Summary:        Python Bindings for libaudit
License:        LGPL-2.1+
Group:          Development/Languages/Python
Provides:       audit-libs-python = %{version}
Obsoletes:      audit-libs-python < %{version}

%description -n python2-audit
The audit-libs-python package contains the bindings for using libaudit
by python.

%package -n python3-audit
Summary:        Python3 Bindings for libaudit
License:        LGPL-2.1+
Group:          Development/Languages/Python
Provides:       audit-libs-python3 = %{version}
Obsoletes:      audit-libs-python3 < %{version}

%description -n python3-audit
The audit-libs-python3 package contains the bindings for using libaudit
by python3.

%package -n audit-audispd-plugins
Summary:        Default plugins for the audit dispatcher
License:        GPL-2.0+
Group:          System/Monitoring

%description -n audit-audispd-plugins
The audit-audispd-plugins package contains plugin components for the
audit dispatcher (audispd).

%prep
# remove selinux policy
rm -rf audisp/plugins/zos-remote/policy
# we don't build prelude
rm -rf audisp/plugins/prelude
%setup -q -n %{_name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
autoreconf -fi
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-Wl,-z,relro,-z,now"
# no krb support (omit --enable-gssapi-krb5=yes), see audit-no-gss.patch
%configure \
	--enable-systemd \
	--libexecdir=%{_libexecdir}/%{_name} \
	--with-apparmor \
	--with-libwrap \
	--with-libcap-ng=yes \
	--disable-static
make %{?_smp_mflags}

%install
%make_install

mkdir -p %{buildroot}%{_localstatedir}/log/audit/
touch %{buildroot}%{_localstatedir}/log/audit/audit.log
mkdir -p %{buildroot}%{_localstatedir}/spool/audit/
# For ghost below, so that old location files will still be there when
# post copy runs
mkdir -p %{buildroot}%{_sysconfdir}/%{_name}/
mkdir -p %{buildroot}%{_sysconfdir}/%{_name}/rules.d/
touch %{buildroot}%{_sysconfdir}/{auditd.conf,audit.rules} %{buildroot}%{_sysconfdir}/audit/auditd.conf
# On platforms with 32 & 64 bit libs, we need to coordinate the timestamp
touch -r ./audit.spec %{buildroot}%{_sysconfdir}/libaudit.conf
# Starting with audit 2.5 no config is installed so start with no rules
install -m 0644 rules/10-no-audit.rules %{buildroot}%{_sysconfdir}/%{_name}/rules.d/audit.rules
# delete redhat scripts, use ours
rm -rf %{buildroot}%{_sysconfdir}/sysconfig/auditd
rm -rf %{buildroot}%{_initddir}/auditd
rm -rf %{buildroot}%{_sysconfdir}/rc.d/init.d
# delete redhat systemd legacy scripts, our systemd doesn't support the feature
# https://lists.fedoraproject.org/pipermail/devel/2012-June/169411.html
rm -rf %{buildroot}%{_libexecdir}/audit
# Clean up some unneeded library files
rm -f %{buildroot}/%{_libdir}/python*/site-packages/{_audit,_auparse,auparse}.{a,la}
rm -rf %{buildroot}/%{_libdir}/python*/site-packages/__pycache__
# cleanup makefiles for the rules (installed by %%docs command)
rm -f %{buildroot}/%{_libdir}/pkgconfig/{audit,auparse}.pc
# cleanup files handled by audit.spec
rm -rf %{buildroot}/%{_datadir}/aclocal/
rm -rf %{buildroot}/%{_includedir}
rm -f %{buildroot}/%{_libdir}/lib{audit,auparse}.*
rm -f %{buildroot}%{_sysconfdir}/libaudit.conf
rm -f %{buildroot}/%{_mandir}/man5/libaudit.conf.5
rm -rf %{buildroot}/%{_mandir}/man3
# Cleanup plugins
#USR-MERGE
mkdir %{buildroot}/sbin/
for prog in auditctl auditd ausearch autrace audispd aureport augenrules; do
  ln -s %{_sbindir}/$prog %{buildroot}/sbin/$prog
done
#END-USR-MERGE
# rcauditd symlink
ln -s service %{buildroot}%{_sbindir}/rcauditd
chmod 0644 %{buildroot}%{_unitdir}/auditd.service

%check
make %{?_smp_mflags} check

%post -n audit
# Save existing audit files if any (from old locations)
if [ -f %{_sysconfdir}/auditd.conf ]; then
   mv %{_sysconfdir}/audit/auditd.conf %{_sysconfdir}/audit/auditd.conf.new
   mv %{_sysconfdir}/auditd.conf %{_sysconfdir}/audit/auditd.conf
fi
if [ -f %{_sysconfdir}/audit.rules ]; then
   mv %{_sysconfdir}/audit.rules %{_sysconfdir}/audit/audit.rules
elif [ ! -f %{_sysconfdir}/audit/audit.rules ]; then
   cp %{_sysconfdir}/audit/rules.d/audit.rules %{_sysconfdir}/audit/audit.rules
fi
%service_add_post auditd.service

%pre -n audit
%service_add_pre auditd.service

%preun -n audit
%service_del_preun auditd.service

%postun -n audit
%service_del_postun auditd.service

%files -n audit
%doc README COPYING ChangeLog rules/[0-9]* rules/README-rules init.d/auditd.cron
%attr(644,root,root) %{_mandir}/man8/audispd.8.gz
%attr(644,root,root) %{_mandir}/man8/auditctl.8.gz
%attr(644,root,root) %{_mandir}/man8/auditd.8.gz
%attr(644,root,root) %{_mandir}/man8/aureport.8.gz
%attr(644,root,root) %{_mandir}/man8/ausearch.8.gz
%attr(644,root,root) %{_mandir}/man8/autrace.8.gz
%attr(644,root,root) %{_mandir}/man8/aulast.8.gz
%attr(644,root,root) %{_mandir}/man8/aulastlog.8.gz
%attr(644,root,root) %{_mandir}/man8/ausyscall.8.gz
%attr(644,root,root) %{_mandir}/man7/audit.rules.7.gz
%attr(644,root,root) %{_mandir}/man5/auditd.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/audispd.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/ausearch-expression.5.gz
%attr(644,root,root) %{_mandir}/man8/auvirt.8.gz
%attr(644,root,root) %{_mandir}/man8/augenrules.8.gz
/sbin/auditctl
%attr(750,root,root) %{_sbindir}/auditctl
/sbin/auditd
%attr(750,root,root) %{_sbindir}/auditd
/sbin/ausearch
%attr(755,root,root) %{_sbindir}/ausearch
/sbin/autrace
%attr(750,root,root) %{_sbindir}/autrace
/sbin/audispd
%attr(750,root,root) %{_sbindir}/augenrules
/sbin/augenrules
%attr(750,root,root) %{_sbindir}/audispd
%attr(755,root,root) %{_bindir}/aulast
%attr(755,root,root) %{_bindir}/aulastlog
%attr(755,root,root) %{_bindir}/ausyscall
/sbin/aureport
%attr(755,root,root) %{_sbindir}/aureport
%attr(755,root,root) %{_bindir}/auvirt
%dir %attr(750,root,root) %{_sysconfdir}/audit
%attr(750,root,root) %dir %{_sysconfdir}/audisp
%attr(750,root,root) %dir %{_sysconfdir}/audisp/plugins.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/plugins.d/af_unix.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/plugins.d/syslog.conf
%ghost %{_sysconfdir}/auditd.conf
%ghost %{_sysconfdir}/audit.rules
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/auditd.conf
%dir %attr(750,root,root) %{_sysconfdir}/audit/rules.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/rules.d/audit.rules
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/audispd.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audit/audit-stop.rules
%dir %attr(700,root,root) %{_localstatedir}/log/audit
%ghost %config(noreplace) %{_localstatedir}/log/audit/audit.log
%dir %attr(700,root,root) %{_localstatedir}/spool/audit
%{_unitdir}/auditd.service
%{_sbindir}/rcauditd

%if %{with python2}
%files -n python2-audit
%attr(755,root,root) %{python2_sitearch}/_audit.so
%attr(755,root,root) %{python2_sitearch}/auparse.so
%{python2_sitearch}/audit.py*
%endif

%if %{with python3}
%files -n python3-audit
%attr(755,root,root) %{python3_sitearch}/_audit.so
%attr(755,root,root) %{python3_sitearch}/auparse.so
%{python3_sitearch}/audit.py*
%endif

%files -n audit-audispd-plugins
%attr(644,root,root) %{_mandir}/man8/audispd-zos-remote.8.gz
%attr(644,root,root) %{_mandir}/man5/zos-remote.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/audisp-remote.conf.5.gz
%attr(644,root,root) %{_mandir}/man8/audisp-remote.8.gz
%attr(750,root,root) %dir %{_sysconfdir}/audisp
%attr(750,root,root) %dir %{_sysconfdir}/audisp/plugins.d
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/plugins.d/audispd-zos-remote.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/zos-remote.conf
%attr(750,root,root) %{_sbindir}/audisp-remote
%attr(750,root,root) %{_sbindir}/audispd-zos-remote
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/audisp-remote.conf
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/audisp/plugins.d/au-remote.conf

%changelog
* Thu Jun  4 2020 Enzo Matsumiya <ematsumiya@suse.com>
- Fix hang on startup (bsc#1156159)
  * audit-Fix-hang-on-startup.patch
* Fri Mar 16 2018 tonyj@suse.com
- Change openldap dependency to client only (bsc#1085003)
* Wed Jan 17 2018 tchvatal@suse.com
- Add conditions around python plugins to allow us to conditionalize
  them in enviroment without python2
* Thu Nov  9 2017 mpluskal@suse.com
- Rename python binding packages to match current python packaging
  standards
- Update python build dependencies to resolve future split of
  python2/3
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 2.8.1. See audit.spec (libaudit1) for upstream
  changelog
- Remove audit-implicit-writev.patch (fixed upstream across 2
  commits)
  * 3b30db20ad983274989ce9a522120c3c225436b3
  * 07132c22314e9abbe64d1031fd8734243285bb3f
- Cleanup with spec-cleaner
* Fri Aug 18 2017 dimstar@opensuse.org
- Add audit-implicit-writev.patch: include sys/uio.h to ensure
  readv and writev are declared.
* Mon Jul 24 2017 jengelh@inai.de
- Rectify RPM groups, diversify descriptions.
- Remove mentions of static libraries because they are not built.
* Tue Jul 18 2017 tonyj@suse.com
- Update to version 2.7.7. See audit.spec (libaudit1) for upstream
  changelog
  Since commit 6cf57d27 (2.7.4) audit is now started as an non-forking
  service (bsc#1042781).
  Add config: audit-stop.rules
  Refresh patch: audit-allow-manual-stop.patch
  Refresh patch: audit-no-gss.patch
* Fri Apr  1 2016 tchvatal@suse.com
- Version update to 2.5. See audit.spec (libaudit1) for upstream
  changelog
- Cleanup with spec-cleaner
- Sort out bit /sbin /usr/sbin/ installation
- Install the rules as documentation
- Remove needless %%py_requires from python subpkgs
* Fri Aug 21 2015 tonyj@suse.com
- Update to version 2.4.4. See audit.spec (libaudit1) for upstream
  changelog
- Add python3 bindings for libaudit and libauparse
- Remove patch 'audit-no_m4_dir.patch'
  (added Fri Apr 26 11:14:39 UTC 2013 by mmeister@suse.com)
  No idea what earlier 'automake' build error this was trying to fix but
  it broke the handling of "--without-libcap-ng". Anyways, no build error
  occurs now and m4 path is also needed in v2.4.4 to find ax_prog_cc_for_build
* Tue Sep  2 2014 tonyj@suse.com
- Update to version 2.4. See audit.spec (libaudit1) for upstream
  changelog
  Drop patch: auditd-donot-start-if-kernel-cmdline-disabled.patch
* Fri Aug 15 2014 crrodriguez@opensuse.org
- If the system has been booted with audit=0 in the kernel cmdline
  auditd.service must refrain from starting as the relevant kernel
  subsystem will be permanently disabled.
  add patch: auditd-donot-start-if-kernel-cmdline-disabled.patch
* Thu Jul 10 2014 tonyj@suse.com
- Do not require tclass field to be present when searching for AVC
  records (bnc#878687)
  add patch: audit-ausearch-do-not-require-tclass.patch
* Tue Apr 15 2014 tonyj@suse.com
- Update to version 2.3.6. See audit.spec (libaudit1) for upstream
  changelog
* Wed Mar 26 2014 crrodriguez@opensuse.org
- fix systemd warning:
  "Configuration file /usr/lib/systemd/system/auditd.service
  is marked world-inaccessible.
  This has no effect as configuration data is accessible
  via APIs without restrictions"
  * indeed restricting access to unit files using filesystem
  permissions is non-sense.
* Thu Feb 27 2014 tonyj@suse.com
- Add systemd requires (bnc#865849)
* Tue Feb  4 2014 tonyj@suse.com
- Update to version 2.3.3. See audit.spec (libaudit1) for upstream
  changelog
* Tue Nov 26 2013 tonyj@suse.com
- Update to version 2.3.2. See audit.spec (libaudit1) for upstream
  changelog
- Drop patch 'audit-fix-implicit-defn.patch' (upstream)
- Add patch 'audit-allow-manual-stop.patch' to reinstate service
  stop/restart.
- /etc/sysconfig/audit still existed but was no longer referenced
  by systemd, so remove
- Delete audit-no_plugins.patch, it was stale (no longer referenced
  by specfiles) but had not been removed.
* Wed Oct  2 2013 opensuse@cboltz.de
- (re-)add rcauditd as symlink to /usr/sbin/service
* Thu Jun 27 2013 tonyj@suse.com
- Eliminate build cycles. audit.spec now builds only libs/devel.
  Remainder (including daemon) built from audit-secondary.spec
- Add patch 'audit-fix-implicit-defn.patch' to fix implicit definition
  warning.
* Mon Mar 25 2013 crrodriguez@opensuse.org
- Buildrequires cap-ng library
* Tue Jan 22 2013 jengelh@inai.de
- Executing autoreconf requires autoconf
* Fri Oct 12 2012 coolo@suse.com
- Update to version 2.2.1, see audit's changes
* Tue Feb 28 2012 tonyj@suse.com
- Update to version 2.1.3.  See audit.spec upstream changelog
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri May 20 2011 tonyj@novell.com
- Adjust license of audit-libs-python to be LGPLv2.1 or later.
* Wed Apr 27 2011 tonyj@novell.com
- Upgrade to version 2.1.1 (see audit.changes for upstream change
  history)
* Wed Sep 29 2010 tonyj@novell.com
- Upgrade to version 2.0.5 (see audit.changes for upstream change
  history)
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Tue May  4 2010 tonyj@suse.de
- Upgrade to version 2.0.4 (see audit.changes for upstream change
  history)
* Sat Jun 20 2009 cmorve69@yahoo.es
- fixed build with --as-needed
* Mon May 11 2009 tonyj@suse.de
- Update from 1.7.7 to 1.7.13 (see audit.changes for upstream change
  history)
* Fri Sep 26 2008 tonyj@suse.de
- Update from 1.7.4 to 1.7.7 (see audit.changes for upstream change
  history)
* Fri Aug  1 2008 ro@suse.de
- disable debuginfo for secondary specfile
* Tue Jun 24 2008 tonyj@suse.de
- Update from 1.7.2 to 1.7.4 (see audit.changes for upstream change
  history)
- Update from 1.6.8 to 1.7.2 (see audit.changes for upstream change
  history)
* Tue Jun  3 2008 coolo@suse.de
- avoid packaging a directory with different permissions (creating
  rpm -V output)
* Wed Apr 16 2008 aj@suse.de
- Use %%py_requires for proper requires.
* Wed Mar 26 2008 tonyj@suse.de
- Update to version 1.6.8.
- Rename to audit-secondary and build audisp-plugins from here
  to minimise bootstrap dependancies.
* Tue Mar 18 2008 schwab@suse.de
- Use autoreconf.
* Wed Oct 10 2007 tonyj@suse.de
- Upgrade to 1.6.2
* Tue Jul 24 2007 tonyj@suse.de
- Upgrade to 1.5.5
    Drop audit-swig-attribute.patch (upstreamed)
* Thu Jul 12 2007 tonyj@suse.de
- Fix build errors on ppc
* Wed Jul 11 2007 tonyj@suse.de
- Upgrade to 1.5.4
* Wed May  2 2007 tonyj@suse.de
- Upgrade to 1.5.3.
* Wed Nov 29 2006 tonyj@suse.de
- Upgrade to 1.2.9 (drop several patches which are now upstream)
- /usr/sbin/audispd now packaged by audit-libs-python
* Sat Nov  4 2006 ro@suse.de
- fix requires
* Thu Aug 31 2006 tonyj@suse.de
- Upgrade to 1.2.6-1
* Wed Aug 16 2006 cthiel@suse.de
- split off package
